==> alvin_airflow-0.0.8-py3-none-any.whl: alvin_airflow/config.py <==
from typing import List
from alvin_airflow.patch.functions import (
    _run_finished_callback,
    handle_failure,
    handle_callback,
    pre_execute,
    get_client,
)
from alvin_airflow.lineage.metadata import create_alvin_dag
from dataclasses import dataclass
import importlib
import os


@dataclass
class AlvinAirflowPatch:
    package_name: str
    function: any
    supported_versions: List[str]
    destination_path: str
    is_required: bool = False

    @property
    def destination(self):
        module_name, class_name = self.destination_path.rsplit(".", 1)
        return getattr(importlib.import_module(module_name), class_name)

    def __repr__(self):
        return (
            f"package_name: {self.package_name}, "
            f"patch: {self.function}, "
            f"supported_versions: {self.supported_versions}, "
            f"destination: {self.destination}"
        )


@dataclass
class AlvinAirflowExtractor:
    package_name: str
    env_name: str
    extractor_path: str
    supported_versions: List[str]

    def __repr__(self):
        return (
            f"package_name: {self.package_name}, "
            f"env_name: {self.env_name}, "
            f"extractor_path: {self.extractor_path}, "
            f"supported_versions: {self.supported_versions}, "
        )


@dataclass
class AlvinDagCreator:
    package_name: str
    function: any
    supported_versions: List[str]

    def __repr__(self):
        return (
            f"function: {self.function}, "
            f"supported_versions: {self.supported_versions}"
        )


patch_list = [
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=_run_finished_callback,
        supported_versions=["2.2.3", "2.2.3+composer"],
        destination_path="airflow.models.taskinstance.TaskInstance",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=handle_failure,
        supported_versions=["1.10.15"],
        destination_path="airflow.models.taskinstance.TaskInstance",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=handle_callback,
        supported_versions=["1.10.15", "2.2.3+composer", "2.2.3"],
        destination_path="airflow.models.dag.DAG",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=pre_execute,
        supported_versions=["1.10.15", "1.10.15+composer"],
        destination_path="airflow.contrib.operators.bigquery_operator.BigQueryOperator",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=get_client,
        supported_versions=["1.10.15", "1.10.15+composer"],
        destination_path="airflow.contrib.hooks.bigquery_hook.BigQueryHook",
    ),
]

extractor_list = [
    AlvinAirflowExtractor(
        package_name="apache-airflow",
        env_name="OPENLINEAGE_EXTRACTOR_BigQueryExecuteQueryOperator",
        extractor_path="alvin_airflow.lineage.extractors.bigquery.AlvinBigQueryExtractor",
        supported_versions=["2.2.3", "2.2.3+composer"],
    ),
    AlvinAirflowExtractor(
        package_name="apache-airflow",
        env_name="OPENLINEAGE_EXTRACTOR_BigQueryOperator",
        extractor_path="alvin_airflow.lineage.extractors.bigquery.AlvinBigQueryLegacyExtractor",
        supported_versions=["1.10.15+composer"],
    ),
]

dags_list = [
    AlvinDagCreator(
        package_name="apache-airflow",
        function=create_alvin_dag,
        supported_versions=["2.2.3", "2.2.3+composer"]
    )
]

ALVIN_BACKEND_API_URL = os.getenv('ALVIN_LINEAGE_BACKEND_URL')
ALVIN_BACKEND_API_KEY = os.getenv('ALVIN_BACKEND_API_KEY')

==> alvin_airflow-0.0.10-py3-none-any.whl: alvin_airflow/config.py <==
from typing import List
from alvin_airflow.patch.functions import (
    _run_finished_callback,
    handle_failure,
    handle_callback,
    pre_execute,
    get_client,
)
from alvin_airflow.lineage.metadata import create_alvin_dag, create_alvin_dag_google_composer
from dataclasses import dataclass
import importlib
import os


@dataclass
class AlvinAirflowPatch:
    package_name: str
    function: any
    supported_versions: List[str]
    destination_path: str
    is_required: bool = False

    @property
    def destination(self):
        module_name, class_name = self.destination_path.rsplit(".", 1)
        return getattr(importlib.import_module(module_name), class_name)

    def __repr__(self):
        return (
            f"package_name: {self.package_name}, "
            f"patch: {self.function}, "
            f"supported_versions: {self.supported_versions}, "
            f"destination: {self.destination}"
        )


@dataclass
class AlvinAirflowExtractor:
    package_name: str
    env_name: str
    extractor_path: str
    supported_versions: List[str]

    def __repr__(self):
        return (
            f"package_name: {self.package_name}, "
            f"env_name: {self.env_name}, "
            f"extractor_path: {self.extractor_path}, "
            f"supported_versions: {self.supported_versions}, "
        )


@dataclass
class AlvinDagCreator:
    package_name: str
    function: any
    supported_versions: List[str]

    def __repr__(self):
        return (
            f"function: {self.function}, "
            f"supported_versions: {self.supported_versions}"
        )


patch_list = [
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=_run_finished_callback,
        supported_versions=["2.2.3", "2.2.3+composer"],
        destination_path="airflow.models.taskinstance.TaskInstance",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=handle_failure,
        supported_versions=["1.10.15"],
        destination_path="airflow.models.taskinstance.TaskInstance",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=handle_callback,
        supported_versions=["1.10.15", "2.2.3+composer", "2.2.3"],
        destination_path="airflow.models.dag.DAG",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=pre_execute,
        supported_versions=["1.10.15", "1.10.15+composer"],
        destination_path="airflow.contrib.operators.bigquery_operator.BigQueryOperator",
    ),
    AlvinAirflowPatch(
        package_name="apache-airflow",
        function=get_client,
        supported_versions=["1.10.15", "1.10.15+composer"],
        destination_path="airflow.contrib.hooks.bigquery_hook.BigQueryHook",
    ),
]

extractor_list = [
    AlvinAirflowExtractor(
        package_name="apache-airflow",
        env_name="OPENLINEAGE_EXTRACTOR_BigQueryExecuteQueryOperator",
        extractor_path="alvin_airflow.lineage.extractors.bigquery.AlvinBigQueryExtractor",
        supported_versions=["2.2.3", "2.2.3+composer"],
    ),
    AlvinAirflowExtractor(
        package_name="apache-airflow",
        env_name="OPENLINEAGE_EXTRACTOR_BigQueryOperator",
        extractor_path="alvin_airflow.lineage.extractors.bigquery.AlvinBigQueryLegacyExtractor",
        supported_versions=["1.10.15+composer"],
    ),
]

dags_list = [
    AlvinDagCreator(
        package_name="apache-airflow",
        function=create_alvin_dag,
        supported_versions=["2.2.3"]
    ),
    AlvinDagCreator(
        package_name="apache-airflow",
        function=create_alvin_dag_google_composer,
        supported_versions=["2.2.3+composer"]
    )
]

ALVIN_BACKEND_API_URL = os.getenv('ALVIN_LINEAGE_BACKEND_URL')

ALVIN_BACKEND_API_KEY = os.getenv('ALVIN_BACKEND_API_KEY')

GOOGLE_COMPOSER_BUCKET = os.getenv('GCS_BUCKET')
